# InfluxDB 3.0 Clustered

## Quick Start

```shell
helm repo add influxdata https://helm.influxdata.com/
helm upgrade --install influxdb influxdata/influxdb3-clustered -f values.yml --namespace influxdb
```

## Introduction

[InfluxDB](https://github.com/influxdata/influxdb) is an open source time series database written in Rust, using Apache Arrow, Apache Parquet, and Apache DataFusion as its foundational building blocks. [InfluxDB Clustered](https://www.influxdata.com/products/influxdb-clustered/) is the evolution of InfluxDB Enterprise, making it the solution for enterprises that need control over their data and underlying infrastructure.

## Installing the Chart

InfluxDB depends on a small number of external services, and these must be configured in your values file. See the [InfludDB Clustered documentation](https://docs.influxdata.com/influxdb/clustered/) for a detailed configuration guide.

To install the chart using the release name `my-release`:

```shell
helm upgrade --install my-release influxdata/influxdb3-clustered -f values.yml
```

InfluxDB Clustered is a complex distributed database, composed of numerous interconnected resources. These resources are managed using the [Kubit operator](https://github.com/kubecfg/kubit/). This helm chart will install that operator and the InfluxDB Clustered AppInstance resource, which encapsulates all of the resources and configuration for the database. Helm cannot be used to bypass the Kubit operator. If you cannot install the operator, then please consult the documentation for alternatives.

## Adopting existing resources into Helm

To allow Helm to take over managing an InfluxDB Clustered AppInstance resource, you must set some helm specific metadata on it, first. Otherwise, Helm will refuse to perform the installation or upgrade. This is a safety feature built into Helm, and is by design.

1. If you have installed the Kubit operator in its own namespace, set `skipOperator: true` in your values file. Normally, the InfluxDB 3.0 Clustered helm chart will deploy the Kubit operator along with the AppInstance resource, as a convenience. However, there's no clear mechanism to adopt existing resources from multiple namespaces into a single helm chart. So you can instead exclude the operator so it will not be managed by Helm.

2. Set your Helm values to match your existing configuration. We recommend using `helm template` to preview the generated resources and diff those against your deployed versions. Replace `DEPLOYMENT-NAME` and `NAMESPACE` to match your existing resources.

```shell
helm template DEPLOYMENT-NAME ./clustered-chart/ -f ./values.yml --namespace NAMESPACE | kubectl diff -f -
```
The AppInstance resource is a little bit more flexible than the Helm template, so there may be some small differences between them that do not actually impact the deployment. It's still best to minimize those differences, which may require updating the existing AppInstance resource slightly to more closely match the resource manifest generated by helm.

3. When you have matched your existing configuration, set the required metadata on your existing AppInstance. Replace `<NAME>` and `<NAMESPACE>` to match your existing resource's name and namespace.

```shell
kubectl label -f example-customer.yml app.kubernetes.io/managed-by=Helm
kubectl annotate -f example-customer.yml meta.helm.sh/release-name=<NAME> meta.helm.sh/release-namespace=<NAMESPACE>
```

4. Helm should now be able to manage the Clustered AppInstance resource. Again, replace `DEPLOYMENT-NAME` and `NAMESPACE` with the appropriate values to match your existing deployment.

```shell
helm install DEPLOYMENT-NAME ./clustered-chart/ -f values.yml --namespace NAMESPACE
```

The expected output will look similar to this, depending on your specific configuration.
```
NAME: clustered
LAST DEPLOYED: Wed Apr 10 17:01:11 2024
NAMESPACE: NAMESPACE
STATUS: deployed
REVISION: 3
TEST SUITE: None
NOTES:
Thank you for installing InfluxDB 3.0 Clustered
Your release is named DEPLOYMENT-NAME
You are running build number 20240326-922145

Our documentation is available at https://docs.influxdata.com/influxdb/clustered/
```
